(hiera project & args)Generate a dependency graph of the namespaces in the project. Accepts keyword options and an optional list of additional source paths to search.
Options may include:
Example usage:
lein hiera :cluster-depth 2 ../project/src
Generate a dependency graph of the namespaces in the project. Accepts keyword options and an optional list of additional source paths to search.
Options may include:
- :dot If set, save the raw DOT graph to this path.
- :path The location to output the graph image to.
- :vertical Specifies whether to lay out the graph vertically or horizontally.
- :show-external When set, the graph will include nodes for namespaces which are not defined in the source files, marked by a dashed border.
- :cluster-depth Sets the number of namespace segments to cluster nodes by. Clusters must contain at least one fewer segment than the nodes themselves.
- :trim-ns-prefix When set, clustered namespaces will have the cluster prefix removed from the node labels.
- :ignore-ns A namespace prefix to exclude from the graph. May be provided multiple times.
Example usage:
lein hiera :cluster-depth 2 ../project/srccljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |